@@ -40,7 +40,7 @@ full_text_urls <- function(doi) {
         ub <- 'http://journals.plos.org/plosclinicaltrials/article/asset?id=%s.XML'
         sprintf(ub, x)
       } else {
-        ub <- 'http://www.%s.org/article/fetchObject.action?uri=info:doi/%s&representation=XML'
+        ub <- 'http://journals.plos.org/%s/article/file?id=%s&type=manuscript'
         sprintf(ub, journal, x)
       }
     }
@@ -86,7 +86,9 @@ plos_fulltext <- function(doi, ...){
   getfulltext <- function(x){
     out <- httr::GET(x, ...)
     httr::warn_for_status(out)
-    stopifnot(out$headers$`content-type` == 'text/xml')
+    if (!out$headers$`content-type` %in% c('application/xml', 'text/xml')) {
+      stop('content-type not one of "application/xml" or "text/xml"', call. = FALSE)
+    }
     utf8cont(out)
   }
   res <- lapply(urls, getfulltext)
@@ -98,7 +100,7 @@ plos_fulltext <- function(doi, ...){
 #' @export
 #' @rdname plos_fulltext
 print.plosft <- function(x, ...){
-  namesprint <- paste(na.omit(names(x)[1:10]), collapse = " ")
+  namesprint <- paste(stats::na.omit(names(x)[1:10]), collapse = " ")
   lengths <- vapply(x, nchar, 1, USE.NAMES = FALSE)
   cat(sprintf("%s full-text articles retrieved", length(x)), "\n")
   cat(sprintf("Min. Length: %s - Max. Length: %s", min(lengths), max(lengths)), "\n")
